from skippy.get_data import get_data
from skippy.split_data import split_data
from skippy.get_model import get_model
from skippy.pickle_model import pickle_model
from skippy.plot import confusion_matrix_plot, residual_plot
from skippy.classification import classification
from skippy.regression import regression

__all__ = ['get_data',
           'split_data',
           'get_model',
           'pickle_model',
           'confusion_matrix_plot',
           'residual_plot',
           'classification',
           'regression']
